# MemoSourceType


## Enum

* `SUBSCRIPTION` (value: `'Subscription'`)

* `STANDALONE` (value: `'Standalone'`)

* `ORDER` (value: `'Order'`)

* `CONSOLIDATION` (value: `'Consolidation'`)

* `INVOICE` (value: `'Invoice'`)

* `CREDITMEMO` (value: `'CreditMemo'`)

* `DEBITMEMO` (value: `'DebitMemo'`)

* `SURCHARGE` (value: `'Surcharge'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


